@@ -44,11 +44,22 @@
 #' @keywords internal
 #'
 #' @examples
+#' # Load floral reflectance spectra
 #' data(flowers)
-#' vis.flowers <- vismodel(flowers)
+#' 
+#' # Estimate quantum catches visual phenotype of a Blue Tit
+#' vis.flowers <- vismodel(flowers, visual = 'bluetit')
+#' 
+#' # Estimate noise-weighted colour distances between all flowers 
 #' cd.flowers <- coldist(vis.flowers)
+#' 
+#' # Convert points to Cartesian coordinates in which Euclidean distances are 
+#' # noise-weighted.
 #' propxyz <- jnd2xyz(cd.flowers)
+#' 
+#' # Plot the floral spectra in 'noise-corrected' space
 #' plot(propxyz)
+#' 
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
 #'
 #' @references Pike, T.W. (2012). Preserving perceptual distances in
@@ -69,12 +80,10 @@ jndplot <- function(x, arrow = c("relative", "absolute", "none"), achro = FALSE,
   oldpar <- par(no.readonly = TRUE)
   on.exit(par(oldpar))
 
-  if (square) {
-    par(pty = "s")
-  }
-
   arg <- list(...)
-
+  if (square) {
+    arg$asp <- 1
+  }
   if (achro) {
     plotdims <- sum(c("x", "y", "z", "lum") %in% colnames(x))
   } else {
