@@ -27,6 +27,7 @@
 #'  of Stockman & Sharpe (2000), as ratified by the CIE (2006).
 #' - `'ctenophorus'`: Ornate dragon lizard *Ctenophorus ornatus*.
 #' - `'musca'`: Housefly *Musca domestica*.
+#' - `'drosophila'`: Vinegar fly *Drosophila melanogaster* (Sharkey et al. 2020).
 #' - `'pfowl'`: Peafowl *Pavo cristatus*.
 #' - `'segment'`: Generic tetrachromat 'viewer' for use in the segment analysis of Endler (1990).
 #' - `'star'`: Starling *Sturnus vulgaris*.
@@ -40,6 +41,7 @@
 #' - `'ch.dc'`: Chicken *Gallus gallus* double cone.
 #' - `'st.dc'`: Starling *Sturnus vulgaris* double cone.
 #' - `'md.r1'`: Housefly *Musca domestica* R1-6 photoreceptor.
+#' - `'dm.r1'`: Vinegar fly *Drosophila melanogaster* R1-6 photoreceptor.
 #' - `'ra.dc'`: Triggerfish *Rhinecanthus aculeatus* double cone.
 #' - `'cf.r'`: Canid *Canis familiaris* cone.
 #' - `'ml'`: the summed response of the two longest-wavelength photoreceptors.
@@ -106,13 +108,14 @@
 #' vis.star <- vismodel(sicalis, visual = "star", achromatic = "bt.dc", relative = FALSE)
 #' dist.star <- coldist(vis.star, achromatic = TRUE)
 #'
-#' # Custom trichromatic visual system
+#' # Estimate quantum catches using a custom trichromatic visual phenotype
 #' custom <- sensmodel(c(330, 440, 550))
 #' names(custom) <- c("wl", "s", "m", "l")
 #' vis.custom <- vismodel(flowers, visual = custom)
 #' tri.custom <- colspace(vis.custom, space = "tri")
+#' 
+#' @author Thomas E. White \email{thomas.white026@@gmail.com}
 #' @author Rafael Maia \email{rm72@@zips.uakron.edu}
-#' @author Thomas White \email{thomas.white026@@gmail.com}
 #'
 #' @references Vorobyev, M., Osorio, D., Bennett, A., Marshall, N., & Cuthill, I.
 #'  (1998). Tetrachromacy, oil droplets and bird plumage colours. Journal Of Comparative
@@ -142,14 +145,21 @@
 #'  Internationale de l' Eclairage.
 #' @references Neitz, J., Geist, T., Jacobs, G.H. (1989) Color vision in the dog.
 #' Visual Neuroscience, 3, 119-125.
+#' @references Sharkey, C. R., Blanco, J., Leibowitz, M. M., Pinto-Benito, D.,
+#' & Wardill, T. J. (2020). The spectral sensitivity of Drosophila photoreceptors.
+#' Scientific reports, 10(1), 1-13.
 #'
 
 vismodel <- function(rspecdata,
                      visual = c(
-                       "avg.uv", "avg.v", "bluetit", "ctenophorus", "star", "pfowl", "apis",
-                       "canis", "cie2", "cie10", "musca", "segment", "habronattus", "rhinecanthus"
+                       "avg.uv", "avg.v", "bluetit", "ctenophorus", "star",
+                       "pfowl", "apis", "canis", "cie2", "cie10", "musca",
+                       "drosophila", "segment", "habronattus", "rhinecanthus"
+                     ),
+                     achromatic = c(
+                       "none", "bt.dc", "ch.dc", "st.dc", "md.r1",
+                       "dm.r1", "ra.dc", "cf.r", "ml", "l", "all"
                      ),
-                     achromatic = c("none", "bt.dc", "ch.dc", "st.dc", "md.r1", "ra.dc", "cf.r", "ml", "l", "all"),
                      illum = c("ideal", "bluesky", "D65", "forestshade"),
                      trans = c("ideal", "bluetit", "blackbird"),
                      qcatch = c("Qi", "fi", "Ei"),
@@ -289,7 +299,7 @@ vismodel <- function(rspecdata,
     bkg <- rep(1, dim(rspecdata)[1])
   }
 
-  # Defining ocular  <- mission
+  # Defining ocular  transmission
   trdat <- transmissiondata
 
   if (tr2 != "user-defined") {
@@ -379,12 +389,13 @@ vismodel <- function(rspecdata,
   # Achromatic contrast
 
   # Calculate lum
-  if (achromatic2 %in% c("bt.dc", "ch.dc", "st.dc", "md.r1", "cf.r", "ra.dc", "ml", "l", "all", "user-defined")) {
+  if (achromatic2 %in% c("bt.dc", "ch.dc", "st.dc", "md.r1", "dm.r1", "cf.r", "ra.dc", "ml", "l", "all", "user-defined")) {
     L <- switch(achromatic2,
       "bt.dc" = ,
       "ch.dc" = ,
       "st.dc" = ,
       "md.r1" = ,
+      "dm.r1" = ,
       "cf.r" = ,
       "ra.dc" = sens[, grep(achromatic2, names(sens))],
       "ml" = rowSums(S[, c(dim(S)[2] - 1, dim(S)[2])]),
