@@ -9,19 +9,19 @@ test_that("summary.colspace", {
 
   vis_sicalis <- vismodel(sicalis)
   tcs_sicalis <- colspace(vis_sicalis)
-  sumtcs_sicalis <- expect_warning(
-    expect_output(summary(tcs_sicalis), "Colorspace & visual"),
+  expect_warning(
+    sumtcs_sicalis <- expect_output(summary(tcs_sicalis), "Colorspace & visual"),
     "Not enough points"
   )
   expect_true(is.na(sumtcs_sicalis$huedisp.m))
   expect_true(is.na(sumtcs_sicalis$huedisp.v))
 
-  summary_subset <- expect_message(summary(tcs_sicalis[, -17]), "subset data")
+  expect_message(summary_subset <- summary(tcs_sicalis[, -17]), "subset data")
   expect_equal(summary_subset, summary.data.frame(tcs_sicalis[, -17]))
 
-  tri_sicalis <- expect_warning(colspace(vismodel(sicalis, "cie10"), "tri"))
+  expect_warning(tri_sicalis <- colspace(vismodel(sicalis, "cie10"), "tri"))
   expect_equal(
-    expect_output(summary(tri_sicalis)),
+    summary(tri_sicalis),
     summary.data.frame(tri_sicalis)
   )
 
