@@ -6,6 +6,6 @@ test_that("summary.vismodel", {
   summary_vis <- expect_output(summary(vis.sicalis), "visual model options")
   expect_s3_class(summary_vis, "table")
 
-  summary_subset <- expect_message(summary(vis.sicalis[, -5]), "subset data")
+  expect_message(summary_subset <- summary(vis.sicalis[, -5]), "subset data")
   expect_identical(summary_subset, summary.data.frame(vis.sicalis[, -5]))
 })
